# VueResizeSensor

A container that supports the resize event. It contains an absolute positioned `<iframe>` element. An inline frame supports the resize event natively. Every time the container resizes, it triggers the resize event of the contained inline frame and the event handler of the inline frame triggers the resize event of the container.

## setup

### npm

```shell
npm install vueresizesensor
```

### ES module

Register the component globally.

```javascript
import Vue from 'vue';
import VueResizeSensor from 'vueresizesensor';

Vue.component(VueResizeSensor.name, VueResizeSensor);
```

*or*

Register the component in the scope of another component.

```javascript
import VueResizeSensor from 'vueresizesensor';

export default {
  components: {
    [VueResizeSensor.name]: VueResizeSensor,
  },
  /*...*/
};
```

### browser

```html
<script src="https://unpkg.com/vue"></script>
<script src="https://unpkg.com/vueresizesensor"></script>
```

If Vue is detected, the component will be registered automatically.

## usage

```html
<vue-resize-sensor
  style="
    height: 100%;
    width: 100%;
  "
>
  <template slot-scope="{w, h}">
    <div
      :style="{flexDirection: w > h ? 'row' : 'column'}"
      style="display: flex;"
    >
      <div><!--...--></div>
      <div><!--...--></div>
    </div>
    <div v-show="h > 400"><!--...--></div>
  </template>
<vue-resize-sensor>
```

---

Capture `resize` event.

```vue
<template>
  <div>
    <vue-resize-sensor
      style="width: 100%;"
      @resize="onResize"
    />
    <!--...-->
  </div>
</template>
<script>
export default {
  /*...*/
  methods: {
    onResize({w}) {
      // handle resize
    },
  },    
};
</script>
```

---

The component renders a `<div>` element by default. You can change the element that is rendered with the `tag` attribute.

```html
<vue-resize-sensor tag="form"><!--...--><vue-resize-sensor>
```
